@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "cuckoo-search" "0.2.6"
+(define-package "cuckoo-search" "20251004.1847"
   "Content-based search and saved-searches for Elfeed."
   '((emacs  "29.1")
     (elfeed "3.4.2"))
